from distutils.core import setup

setup(
    name='spacyss',
    version='1.0.1',
    packages=['seg', 'seg.newline', 'seg.singsent'],
    url='https://github.com/tc64/spacyss',
    license='',
    author='Taylor Cassidy',
    author_email='taylorcassidy64@gmail.com',
    description='sentence segmenters for spacy2.0+'
)

# Nothing to set up at the moment!
